<?php
/**
 * Functions which enhance the theme by hooking into WordPress
 * 
 */

if ( ! function_exists( 'wp_body_open' ) ) {

	function wp_body_open() {
		/**
		 * Triggered after the opening <body> tag.
		 */
		do_action( 'wp_body_open' );
	}
}

if ( ! function_exists( 'industri_body_classes' ) ) {
/**
 * Adds custom classes to the array of body classes.
 *
 * @since industri 1.0
 *
 * @return void
 */
function industri_body_classes( $classes ) {

	if ( is_multi_author() ) {
		$classes[] = 'group-blog';
	}
	
	// body class
	$classes[] = 'industri-body';

	// Helps detect if JS is enabled or not.
	$classes[] = 'no-js';

	// Adds `singular` to singular pages, and `hfeed` to all other pages.
	$classes[] = is_singular() ? 'singular' : 'hfeed';	

	return $classes;
}
add_filter( 'body_class', 'industri_body_classes' );
}



if ( ! function_exists( 'industri_post_classes' ) ) {
/**
 * Adds custom class to the array of posts classes.
 *
 * @since Industri 1.0
 *
 * @return void
 */
function industri_post_classes( $classes ) {
	$classes[] = 'entry';
	return $classes;
}
add_filter( 'post_class', 'industri_post_classes', 10, 3 );

}


if ( ! function_exists( 'industri_comment_form_defaults' ) ) {
	function industri_comment_form_defaults( $defaults ) {

	// Adjust height of comment form.
		$defaults['comment_field'] = preg_replace( '/rows="\d+"/', 'rows="5"', $defaults['comment_field'] );

		return $defaults;
	}	

	add_filter( 'comment_form_defaults', 'industri_comment_form_defaults' ) ;	

}

if ( ! function_exists( 'industri_jetpack_social_menu' ) ) {

	// jetpack social menu
	function industri_jetpack_social_menu() {

		if ( ! function_exists( 'jetpack_social_menu' ) ) {
			return;
		} else {
			jetpack_social_menu();
		}
	}
	add_action( 'init', 'industri_jetpack_social_menu' );

}

if ( ! function_exists( 'industri_print_first_instance_of_block' ) ) {
/**
 * Print the first instance of a block in the content, and then break away.
 * 
 */
function industri_print_first_instance_of_block( $block_name, $content = null, $instances = 1 ) {
	$instances_count = 0;
	$blocks_content  = '';

	if ( ! $content ) {
		$content = get_the_content();
	}

	// Parse blocks in the content.
	$blocks = parse_blocks( $content );

	// Loop blocks.
	foreach ( $blocks as $block ) {

		// Sanity check.
		if ( ! isset( $block['blockName'] ) ) {
			continue;
		}

		// Check if this the block matches the $block_name.
		$is_matching_block = false;

		// If the block ends with *, try to match the first portion.
		if ( '*' === $block_name[-1] ) {
			$is_matching_block = 0 === strpos( $block['blockName'], rtrim( $block_name, '*' ) );
		} else {
			$is_matching_block = $block_name === $block['blockName'];
		}

		if ( $is_matching_block ) {
			// Increment count.
			$instances_count++;

			// Add the block HTML.
			$blocks_content .= render_block( $block );

			// Break the loop if the $instances count was reached.
			if ( $instances_count >= $instances ) {
				break;
			}
		}
	}

	if ( $blocks_content ) {
		echo apply_filters( 'the_content', $blocks_content ); // phpcs:ignore WordPress.Security.EscapeOutput
		return true;
	}

	return false;
}

}

if ( ! function_exists( 'industri_breadcrumb_title' ) ) {
 //Theme breadcrumb title

	function industri_breadcrumb_title(){
		
		if ( is_front_page() || is_home() ){

			single_post_title();

		}elseif ( is_category() ){

			printf( __( 'Category Archives: %s', 'industri' ), ( single_cat_title( '', false ) ));

		}elseif ( is_tag() ){

			printf( __( 'Tag Archives: %s', 'industri' ), ( single_tag_title( '', false ) ));

		}elseif ( is_404() ){

			printf( __( 'Error 404', 'industri' ));

		}elseif ( is_author() ){

			printf( __( 'Author: %s', 'industri' ), ( get_the_author( '', false ) ));		

		}elseif ( is_day() ) { 

			printf( __( 'Daily Archives: %s', 'industri' ), get_the_date() );

		}elseif ( is_month() ){

			printf( __( 'Monthly Archives: %s', 'industri' ), ( get_the_date( 'F Y' ) ));

		}elseif ( is_year() ) {

			printf( __( 'Yearly Archives: %s', 'industri' ), ( get_the_date( 'Y' ) ) );

		}else {
			the_title();
		}

	}

}


if ( ! function_exists( 'industri_breadcrumb_content' ) ) {

	function industri_breadcrumb_content() {
		
	$showOnHome	= esc_html__('1','industri'); 	// 1 - Show breadcrumbs on the homepage, 0 - don't show
	$delimiter 	= '';   // Delimiter between breadcrumb
	$home 		= esc_html__('Home','industri'); 	// Text for the 'Home' link
	$showCurrent= esc_html__('1','industri'); // Current post/page title in breadcrumb in use 1, Use 0 for don't show
	$before		= '<li class="active">'; // Tag before the current Breadcrumb
	$after 		= '</li>'; // Tag after the current Breadcrumb
	$seprator	= get_theme_mod('seprator','/');

	global $post;
	$homeLink = home_url();

	if (is_home() || is_front_page()) {
		
		if ($showOnHome == 1) echo '<li><a href="' . esc_url($homeLink) . '">' . esc_html($home) . '</a></li>';
		
	} else {
		
		echo '<li><a href="' . esc_url($homeLink) . '">' . esc_html($home) . '</a> ' . '&nbsp' . wp_kses_post($seprator) . '&nbsp';
		
		if ( is_category() ) 
		{
			$thisCat = get_category(get_query_var('cat'), false);
			if ($thisCat->parent != 0) echo get_category_parents($thisCat->parent, TRUE, ' ' . ' ');
			echo $before . esc_html__('Archive by category','industri').' "' . esc_html(single_cat_title('', false)) . '"' .$after;
			
		} 
		
		elseif ( is_search() ) 
		{
			echo $before . esc_html__('Search results for ','industri').' "' . esc_html(get_search_query()) . '"' . $after;
		} 
		
		elseif ( is_day() )
		{
			echo '<a href="' . esc_url(get_year_link(get_the_time('Y'))) . '">' . esc_html(get_the_time('Y')) . '</a> ' . '&nbsp' . wp_kses_post($seprator) . '&nbsp';
			echo '<a href="' . esc_url(get_month_link(get_the_time('Y'),get_the_time('m'))) . '">' . esc_html(get_the_time('F')) . '</a> '. '&nbsp' . wp_kses_post($seprator) . '&nbsp';
			echo $before . esc_html(get_the_time('d')) . $after;
		} 
		
		elseif ( is_month() )
		{
			echo '<a href="' . esc_url(get_year_link(get_the_time('Y'))) . '">' . esc_html(get_the_time('Y')) . '</a> ' . esc_attr($delimiter) . '&nbsp' . wp_kses_post($seprator) . '&nbsp';
			echo $before . esc_html(get_the_time('F')) . $after;
		} 
		
		elseif ( is_year() )
		{
			echo $before . esc_html(get_the_time('Y')) . $after;
		} 
		
		elseif ( is_single() && !is_attachment() )
		{
			if ( get_post_type() != 'post' )
			{
				$post_type = get_post_type_object(get_post_type());
				$slug = $post_type->rewrite;
				echo '<a href="' . esc_url($homeLink) . '/' . $slug['slug'] . '/">' . $post_type->labels->singular_name . '</a>';
				if ($showCurrent == 1) echo ' ' . esc_attr($delimiter) . '&nbsp' . wp_kses_post($seprator) . '&nbsp' . $before . wp_kses_post(get_the_title()) . $after;
			}
			else
			{
				if ($showCurrent == 1) echo $before . esc_html(get_the_title()) . $after;
			}
			
		}
		
		elseif ( !is_single() && !is_page() && get_post_type() != 'post' && !is_404() ) {
			if ( class_exists( 'WooCommerce' ) ) {
				if ( is_shop() ) {
					$thisshop = woocommerce_page_title();
				}
			}	
			else  {
				$post_type = get_post_type_object(get_post_type());
				echo $before . $post_type->labels->singular_name . $after;
			}	
		} 
		
		elseif ( !is_single() && !is_page() && get_post_type() != 'post' && !is_404() ) 
		{
			$post_type = get_post_type_object(get_post_type());
			echo $before . $post_type->labels->singular_name . $after;
		} 
		
		elseif ( is_attachment() ) 
		{
			$parent = get_post($post->post_parent);
			$cat = get_the_category($parent->ID); 
			if(!empty($cat)){
				$cat = $cat[0];
				echo get_category_parents($cat, TRUE, ' ' . esc_attr($delimiter) . '&nbsp' . wp_kses_post($seprator) . '&nbsp');
			}
			echo '<a href="' . esc_url(get_permalink($parent)) . '">' . $parent->post_title . '</a>';
			if ($showCurrent == 1) echo ' ' . esc_attr($delimiter) . ' ' . $before . esc_html(get_the_title()) . $after;
			
		} 
		
		elseif ( is_page() && !$post->post_parent ) 
		{
			if ($showCurrent == 1) echo $before . esc_html(get_the_title()) . $after;
		} 
		
		elseif ( is_page() && $post->post_parent ) 
		{
			$parent_id  = $post->post_parent;
			$breadcrumbs = array();
			while ($parent_id) 
			{
				$page = get_page($parent_id);
				$breadcrumbs[] = '<a href="' . esc_url(get_permalink($page->ID)) . '">' . esc_html(get_the_title($page->ID)) . '</a>' . '&nbsp' . wp_kses_post($seprator) . '&nbsp';
				$parent_id  = $page->post_parent;
			}
			
			$breadcrumbs = array_reverse($breadcrumbs);
			for ($i = 0; $i < count($breadcrumbs); $i++) 
			{
				echo $breadcrumbs[$i];
				if ($i != count($breadcrumbs)-1) echo ' ' . esc_attr($delimiter) . '&nbsp' . wp_kses_post($seprator) . '&nbsp';
			}
			if ($showCurrent == 1) echo ' ' . esc_attr($delimiter) . ' ' . $before . esc_html(get_the_title()) . $after;
			
		} 
		elseif ( is_tag() ) 
		{
			echo $before . esc_html__('Posts tagged ','industri').' "' . esc_html(single_tag_title('', false)) . '"' . $after;
		} 
		
		elseif ( is_author() ) {
			global $author;
			$userdata = get_userdata($author);
			echo $before . esc_html__('Articles posted by ','industri').'' . $userdata->display_name . $after;
		} 
		
		elseif ( is_404() ) {
			echo $before . esc_html__('Error 404 ','industri'). $after;
		}
		
		if ( get_query_var('paged') ) {
			if ( is_category() || is_day() || is_month() || is_year() || is_search() || is_tag() || is_author() ) echo '';
			echo ' ( ' . esc_html__('Page','industri') . '' . esc_html(get_query_var('paged')). ' )';
			if ( is_category() || is_day() || is_month() || is_year() || is_search() || is_tag() || is_author() ) echo '';
		}
		
		echo '</li>';
		
	}
}
}

